package com.srs.teacher.mapper;

import java.util.List;

import com.srs.teacher.domain.SysTeacherResearch;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * researchMapper接口
 *
 * @author srs
 * @date 2024-06-29
 */
public interface SysTeacherResearchMapper extends BaseMapper<SysTeacherResearch> {
    /**
     * 查询research
     *
     * @param researchId research主键
     * @return research
     */
    public SysTeacherResearch selectSysTeacherResearchByResearchId(Long researchId);

    /**
     * 查询research列表
     *
     * @param sysTeacherResearch research
     * @return research集合
     */
    List<SysTeacherResearch> selectSysTeacherResearchList(SysTeacherResearch sysTeacherResearch);

    /**
     * 新增research
     *
     * @param sysTeacherResearch research
     * @return 结果
     */
    int insertSysTeacherResearch(SysTeacherResearch sysTeacherResearch);

    /**
     * 修改research
     *
     * @param sysTeacherResearch research
     * @return 结果
     */
    int updateSysTeacherResearch(SysTeacherResearch sysTeacherResearch);

    /**
     * 删除research
     *
     * @param researchId research主键
     * @return 结果
     */
    int deleteSysTeacherResearchByResearchId(Long researchId);

    /**
     * 批量删除research
     *
     * @param researchIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysTeacherResearchByResearchIds(Long[] researchIds);
}
